@@ -6,15 +6,15 @@
 #define __M4RI_HAVE_POSIX_MEMALIGN	1
 #define __M4RI_HAVE_SSE2		1
 #define __M4RI_HAVE_OPENMP		0
-#define __M4RI_CPU_L1_CACHE		65536
-#define __M4RI_CPU_L2_CACHE		524288
-#define __M4RI_CPU_L3_CACHE		524288
+#define __M4RI_CPU_L1_CACHE		32768
+#define __M4RI_CPU_L2_CACHE		262144
+#define __M4RI_CPU_L3_CACHE		8388608
 #define __M4RI_DEBUG_DUMP		(0 || 0)
 #define __M4RI_DEBUG_MZD		0
 #define __M4RI_HAVE_LIBPNG              1
 
 #define __M4RI_CC                       "gcc"
-#define __M4RI_CFLAGS                   " -mmmx -msse -msse2 -msse3  -march=x86-64 -mtune=generic -O2 -pipe -fstack-protector-strong"
+#define __M4RI_CFLAGS                   " -mmmx -msse -msse2 -msse3  -march=x86-64 -mtune=generic -O2 -pipe -fstack-protector-strong -fno-plt"
 #define __M4RI_SIMD_CFLAGS              " -mmmx -msse -msse2 -msse3"
 #define __M4RI_OPENMP_CFLAGS            ""
 
